* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Notifications Center](https://help.sap.com/docs/leanix/ea/notifications-center)
  * Configuring the Microsoft Teams Channel
